'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _consola = require('consola');

var _consola2 = _interopRequireDefault(_consola);

var _draftlog = require('draftlog');

var _draftlog2 = _interopRequireDefault(_draftlog);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _prettyTime = require('pretty-time');

var _prettyTime2 = _interopRequireDefault(_prettyTime);

var _cli = require('../utils/cli');

var _utils = require('../utils');

var _request = require('../utils/request');

var _consts = require('../utils/consts');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Convention: Original values are kept with two underscores

const globalConsole = {
  log: console.__log || console.log, // eslint-disable-line no-console
  _stdout: console._stdout // eslint-disable-line no-console
};

const renderT = (0, _utils.throttle)((fn, ...args) => fn(...args), 1, 50);

class BarsReporter {
  constructor() {
    this._render = this._render.bind(this);
    this.drafts = null;
  }

  compiling() {
    if (!globalConsole.draft) {
      (0, _draftlog2.default)(globalConsole);
      console.__stdout = console._stdout; // eslint-disable-line no-console
      console._stdout = globalConsole._stdout; // eslint-disable-line no-console
    }

    _consola2.default.pause();
    globalConsole.log();
    this.drafts = [globalConsole.draft(), globalConsole.draft()];
  }

  done() {
    // eslint-disable-next-line no-console
    // if (console.__stdout) {
    //   console._stdout = console.__stdout; // eslint-disable-line no-console
    //   delete console.__stdout; // eslint-disable-line no-console
    // }
    _consola2.default.resume();
  }

  compiled(context) {
    this._render(context);
  }

  update(context) {
    renderT(this._render, context);
  }

  _render(context) {
    const {
      state,
      options: { stream, name }
    } = context;

    const columns = stream.columns || 80;
    const color = (0, _cli.colorize)(state.color);

    if (!state.isRunning) {
      const color2 = state.progress === 100 ? color : _chalk2.default.grey;

      const line1 = color2(`${_consts.TICK} ${name}`);
      const time = (0, _prettyTime2.default)(state.elapsed, 2);
      const line2 = _chalk2.default.grey(`  Compiled succesfuly in ${time}`);

      this.drafts[0](line1);
      this.drafts[1](line2);
    } else {
      const line1 = [color(_consts.BULLET), color(name), (0, _cli.renderBar)(state.progress, state.color), state.msg, `(${state.progress || 0}%)`, _chalk2.default.grey(state.details && state.details[0] || ''), _chalk2.default.grey(state.details && state.details[1] || '')].join(' ');

      const line2 = state.request ? '  ' + _chalk2.default.grey((0, _cli.ellipsisLeft)((0, _request.formatRequest)(state.request), columns - 2)) : '';

      this.drafts[0](line1);
      this.drafts[1](line2);
    }
  }
}
exports.default = BarsReporter;